"use strict";
(self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] = self["webpackChunk_JUPYTERLAB_CORE_OUTPUT"] || []).push([[5562],{

/***/ 15562:
/***/ ((__unused_webpack_module, __webpack_exports__, __webpack_require__) => {

/* harmony export */ __webpack_require__.d(__webpack_exports__, {
/* harmony export */   createGitGraphServices: () => (/* reexport safe */ _chunk_4F5CHEZ2_mjs__WEBPACK_IMPORTED_MODULE_0__.z)
/* harmony export */ });
/* harmony import */ var _chunk_4F5CHEZ2_mjs__WEBPACK_IMPORTED_MODULE_0__ = __webpack_require__(90929);
/* harmony import */ var _chunk_TCCFYFTB_mjs__WEBPACK_IMPORTED_MODULE_1__ = __webpack_require__(68742);





/***/ })

}]);
//# sourceMappingURL=5562.d4c9569c059d4b98e947.js.map?v=d4c9569c059d4b98e947